pm4py.objects.conversion.dfg package
====================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.objects.conversion.dfg.variants

Submodules
----------

pm4py.objects.conversion.dfg.converter module
---------------------------------------------

.. automodule:: pm4py.objects.conversion.dfg.converter
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.objects.conversion.dfg
   :members:
   :undoc-members:
   :show-inheritance:
